==> mx-cleanup_25.5.01.tar.xz: BUILD/translations/mx-cleanup_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="122"/>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>MX Cleanup</source>
        <translation>MX Opruimen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="666"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>Main</source>
        <translation>Hoofd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>Tools</source>
        <translation>Gereedschap</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Removal Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Empty Trash</source>
        <translation>Prullenbak Legen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Trash older than:</source>
        <translation>Afval ouder dan:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.ui" line="489"/>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> days</source>
        <translation>dagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All users</source>
        <translation>Alle gebruikers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>Selected user</source>
        <translation>Geselecteerde gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="369"/>
        <source>Clear APT Cache</source>
        <translation>Ruim Apt Cache op</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>Old files</source>
        <translation>Oude bestanden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="585"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Grafisch Gereedschap voor het Analyseren van Schijfgebruik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="597"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Schijfgebruik Analyse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Schedule</source>
        <translation>Schema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>No automatic clean</source>
        <translation>Geen automatische schoonmaak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>At reboot</source>
        <translation>Bij herstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>Daily</source>
        <translation>Dagelijks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Weekly</source>
        <translation>Wekelijks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Monthly</source>
        <translation>Maandelijks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Free Disk Space for User</source>
        <translation>Vrije Schijfruimte voor Gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Select user to repair</source>
        <translation>Selecteer een gebruiker voor reparatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Select user:</source>
        <translation>Selecteer gebruiker:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Delete Logs</source>
        <translation>Verwijder Logs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>All logs</source>
        <translation>Alle logs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Old logs</source>
        <translation>Oude logs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Logs older than:</source>
        <translation>Logs ouder dan:</translation>
    </message>
    <message>
        <source>Removal tool</source>
        <translation type="vanished">Verwijderingsgereedschap</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Ongebruikte wifi-stuurprogramma&apos;s verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="550"/>
        <source>List and select kernels to remove</source>
        <translation>Lijst en selectie van te verwijderen kernels</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Clean Flatpak</source>
        <translation>Schoonmaken Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Remove unused runtimes</source>
        <translation>Ongebruikte looptijden verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Clean Folders</source>
        <translation>Folders om te Schonen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Not accessed for:</source>
        <translation>Niet toegankelijk voor:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>All (potentially dangerous)</source>
        <translation>Alle (potentieel gevaarlijk)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Thumbnails</source>
        <translation>Thumbnails</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Remove Manuals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>No manuals to remove.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Removing packages, please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Press any key to close</source>
        <translation>Druk een toets om te sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> day</source>
        <translation>dag</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Failed to elevate privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Cleanup script will run at reboot</source>
        <translation>Opschoonscript wordt uitgevoerd bij opnieuw opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Cleanup command done</source>
        <translation>Opruim commando klaar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB werd vrijgemaakt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Quick and safe removal of old files</source>
        <translation>Snelle en veilige verwijdering van oude bestanden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="675"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Kernel momenteel in gebruik:&lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>Remove selected</source>
        <translation>Verwijder geselecteerde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Soortgelijke kernels die kunnen worden verwijderd:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <source>Other kernels that can be removed:</source>
        <translation>Andere kernels die kunnen worden verwijderd:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Niets om te verwijderen.&lt;/b&gt; Kan kernel in gebruik niet verwijderen.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Snel en veilig oude bestanden verwijderen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>U lijkt ingelogd te zijn als root, gelieve uit te loggen en in te loggen als normale gebruiker om dit programma te gebruiken.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Je moet dit programma uitvoeren met admin-toegang.</translation>
    </message>
</context>
</TS>

==> mx-cleanup_25.6.tar.xz: BUILD/translations/mx-cleanup_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="122"/>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>MX Cleanup</source>
        <translation>MX Opruimen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Display help </source>
        <translation>Toon help</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="666"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="638"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>Main</source>
        <translation>Hoofd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>Tools</source>
        <translation>Gereedschap</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Removal Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Remove MX manuals for languages other than system default</source>
        <translation>MX-handleidingen voor andere talen dan de systeemstandaard verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>Empty Trash</source>
        <translation>Prullenbak Legen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Trash older than:</source>
        <translation>Afval ouder dan:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.ui" line="489"/>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> days</source>
        <translation>dagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All users</source>
        <translation>Alle gebruikers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>Selected user</source>
        <translation>Geselecteerde gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="369"/>
        <source>Clear APT Cache</source>
        <translation>Ruim Apt Cache op</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>Old files</source>
        <translation>Oude bestanden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="585"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Grafisch Gereedschap voor het Analyseren van Schijfgebruik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="597"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Schijfgebruik Analyse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Schedule</source>
        <translation>Schema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>No automatic clean</source>
        <translation>Geen automatische schoonmaak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>At reboot</source>
        <translation>Bij herstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="326"/>
        <source>Daily</source>
        <translation>Dagelijks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Weekly</source>
        <translation>Wekelijks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Monthly</source>
        <translation>Maandelijks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>Free Disk Space for User</source>
        <translation>Vrije Schijfruimte voor Gebruiker</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Select user to repair</source>
        <translation>Selecteer een gebruiker voor reparatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Select user:</source>
        <translation>Selecteer gebruiker:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Delete Logs</source>
        <translation>Verwijder Logs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>All logs</source>
        <translation>Alle logs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Old logs</source>
        <translation>Oude logs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Logs older than:</source>
        <translation>Logs ouder dan:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Ongebruikte wifi-stuurprogramma&apos;s verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="550"/>
        <source>List and select kernels to remove</source>
        <translation>Lijst en selectie van te verwijderen kernels</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="36"/>
        <source>Clean Flatpak</source>
        <translation>Schoonmaken Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Remove unused runtimes</source>
        <translation>Ongebruikte looptijden verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Clean Folders</source>
        <translation>Folders om te Schonen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Not accessed for:</source>
        <translation>Niet toegankelijk voor:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="114"/>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>All (potentially dangerous)</source>
        <translation>Alle (potentieel gevaarlijk)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Thumbnails</source>
        <translation>Thumbnails</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Remove Manuals</source>
        <translation>Handleidingen verwijderen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>No manuals to remove.</source>
        <translation>Geen handleidingen om te verwijderen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Removing packages, please wait</source>
        <translation>Pakketten worden verwijderd, even geduld alstublieft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Press any key to close</source>
        <translation>Druk een toets om te sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source> day</source>
        <translation>dag</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Failed to elevate privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Done</source>
        <translation>Klaar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Cleanup script will run at reboot</source>
        <translation>Opschoonscript wordt uitgevoerd bij opnieuw opstarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Cleanup command done</source>
        <translation>Opruim commando klaar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB werd vrijgemaakt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="580"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>Quick and safe removal of old files</source>
        <translation>Snelle en veilige verwijdering van oude bestanden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="585"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="592"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="675"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Kernel momenteel in gebruik:&lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>Remove selected</source>
        <translation>Verwijder geselecteerde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Soortgelijke kernels die kunnen worden verwijderd:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <source>Other kernels that can be removed:</source>
        <translation>Andere kernels die kunnen worden verwijderd:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Niets om te verwijderen.&lt;/b&gt; Kan kernel in gebruik niet verwijderen.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Snel en veilig oude bestanden verwijderen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>U lijkt ingelogd te zijn als root, gelieve uit te loggen en in te loggen als normale gebruiker om dit programma te gebruiken.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Je moet dit programma uitvoeren met admin-toegang.</translation>
    </message>
</context>
</TS>
